/*
 * GeometryRegistry.hpp
 *
 *  Created on: Mar 25, 2017
 *      Author: heber
 */

#ifndef GEOMETRY_GEOMETRYREGISTRY_HPP_
#define GEOMETRY_GEOMETRYREGISTRY_HPP_


// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <map>

#include "CodePatterns/Observer/Observable.hpp"
#include "CodePatterns/Registry.hpp"
#include "CodePatterns/Singleton.hpp"

#include "Geometry/GeometryObject.hpp"


/** The class GeometryRegistry stores all known GeometryObject's for
 * retrieval.
 */
class GeometryRegistry :
    public Singleton<GeometryRegistry>,
    public Registry<GeometryObject>,
    public Observable
{
  friend class Singleton<GeometryRegistry>;

public:
  void addGeometry(const GeometryObject &_v);
  void removeGeometry(const std::string &_name);

  enum NotificationType {
    GeometryInserted,
    GeometryRemoved,
    NotificationType_MAX
  };

  GeometryObject *lastChanged() const { return _lastchanged;  }

private:
  void fillRegistry();

  // private constructor and destructor due to singleton
  GeometryRegistry();
  virtual ~GeometryRegistry();

  GeometryObject *_lastchanged;
};

#endif /* GEOMETRY_GEOMETRYREGISTRY_HPP_ */
